@@ -123,6 +123,7 @@ from typing import (
     Dict,
     Iterable,
     BinaryIO,
+    Set,
     Type,
     TypeVar,
     Union,
@@ -141,7 +142,6 @@ from argparse import (
     ONE_OR_MORE,
     OPTIONAL,
     REMAINDER,
-    SUPPRESS,
     ZERO_OR_MORE
 )
 
@@ -166,6 +166,14 @@ class RefineryPartialResult(ValueError):
         return self.message
 
 
+class RefineryImportMissing(ImportError):
+    def __init__(self, *dependencies: str):
+        super().__init__()
+        import shlex
+        self.install = ' '.join(shlex.quote(dist) for dist in dependencies)
+        self.dependencies = dependencies
+
+
 class RefineryCriticalException(RuntimeError):
     """
     If this exception is thrown, processing of the entire input stream
@@ -308,10 +316,10 @@ class arg(Argument):
 
     @staticmethod
     def switch(
-        *args: str, off=False,
-        help : Union[omit, str] = omit,
-        dest : Union[omit, str] = omit,
-        group: Optional[str] = None,
+        *args   : str, off=False,
+        help    : Union[omit, str] = omit,
+        dest    : Union[omit, str] = omit,
+        group   : Optional[str] = None,
     ) -> Argument:
         """
         A convenience method to add argparse arguments that change a boolean value from True to False or
@@ -321,11 +329,11 @@ class arg(Argument):
 
     @staticmethod
     def binary(
-        *args: str,
-        help : Union[omit, str] = omit,
-        dest : Union[omit, str] = omit,
+        *args   : str,
+        help    : Union[omit, str] = omit,
+        dest    : Union[omit, str] = omit,
         metavar : Optional[str] = None,
-        group: Optional[str] = None,
+        group   : Optional[str] = None,
     ) -> Argument:
         """
         Used to add argparse arguments that contain binary data.
@@ -334,12 +342,12 @@ class arg(Argument):
 
     @staticmethod
     def number(
-        *args: str,
-        bound: Union[omit, Tuple[int, int]] = omit,
-        help : Union[omit, str] = omit,
-        dest : Union[omit, str] = omit,
+        *args   : str,
+        bound   : Union[omit, Tuple[int, int]] = omit,
+        help    : Union[omit, str] = omit,
+        dest    : Union[omit, str] = omit,
         metavar : Optional[str] = None,
-        group: Optional[str] = None,
+        group   : Optional[str] = None,
     ) -> Argument:
         """
         Used to add argparse arguments that contain a number.
@@ -352,11 +360,12 @@ class arg(Argument):
 
     @staticmethod
     def option(
-        *args: str, choices: Enum,
-        help : Union[omit, str] = omit,
-        dest : Union[omit, str] = omit,
-        metavar: Optional[str] = None,
-        group: Optional[str] = None,
+        *args   : str,
+        choices : Enum,
+        help    : Union[omit, str] = omit,
+        dest    : Union[omit, str] = omit,
+        metavar : Optional[str] = None,
+        group   : Optional[str] = None,
     ) -> Argument:
         """
         Used to add argparse arguments with a fixed set of options, based on an enumeration.
@@ -367,7 +376,8 @@ class arg(Argument):
 
     @staticmethod
     def choice(
-        *args: str, choices : List[str],
+        *args   : str,
+        choices : List[str],
         help    : Union[omit, str] = omit,
         metavar : Union[omit, str] = omit,
         dest    : Union[omit, str] = omit,
@@ -800,6 +810,13 @@ class Executable(ABCMeta):
     def name(cls) -> str:
         return cls.__name__.replace('_', '-')
 
+
+    logging.addLevelName(logging.CRITICAL, 'failure') # noqa
+    logging.addLevelName(logging.ERROR,    'failure') # noqa
+    logging.addLevelName(logging.WARNING,  'warning') # noqa
+    logging.addLevelName(logging.INFO,     'comment') # noqa
+    logging.addLevelName(logging.DEBUG,    'verbose') # noqa
+
     @property
     def logger(cls) -> logging.Logger:
         try:
@@ -810,7 +827,7 @@ class Executable(ABCMeta):
         if not logger.hasHandlers():
             stream = logging.StreamHandler()
             stream.setFormatter(logging.Formatter(
-                '[{asctime!s:.5s}][{levelname:.1s}] {name}: {message}',
+                '({asctime}) {levelname} in {name}: {message}',
                 style='{',
                 datefmt='%I:%M:%S'
             ))
@@ -1010,6 +1027,41 @@ class Unit(UnitBase, abstract=True):
     implement the _framing_ syntax for producing multiple outputs and ingesting
     multiple inputs in a common format. For more details, see `refinery.lib.frame`.
     """
+    Arg = arg
+
+    optional_dependencies: Optional[Set[str]] = None
+    required_dependencies: Optional[Set[str]] = None
+
+    @staticmethod
+    def Requires(distribution: str, optional: bool = True):
+        class Requirement(property):
+            dependency = distribution
+            prefix = 'optional' if optional else 'required'
+
+            def __init__(self, importer: Callable):
+                super().__init__(importer)
+                self.module = None
+
+            def __set_name__(self, unit: Type[Unit], name: str):
+                bucket = F'{self.prefix}_dependencies'
+                dep = getattr(unit, bucket)
+                if dep is None:
+                    dep = set()
+                    setattr(unit, bucket, dep)
+                dep.add(self.dependency)
+
+            def __get__(self, unit: Optional[Type[Unit]], tp: Optional[Type[Executable]] = None):
+                if self.module is not None:
+                    return self.module
+                try:
+                    self.module = module = super().fget()
+                except ImportError as E:
+                    raise RefineryImportMissing(*unit.optional_dependencies) from E
+                else:
+                    return module
+
+        return Requirement
+
     @property
     def is_reversible(self) -> bool:
         return self.__class__.is_reversible
@@ -1019,8 +1071,9 @@ class Unit(UnitBase, abstract=True):
         return self.__class__.codec
 
     @property
-    def logger(self) -> logging.Logger:
-        return self.__class__.logger
+    def logger(self):
+        logger: logging.Logger = self.__class__.logger
+        return logger
 
     @property
     def name(self) -> str:
@@ -1084,8 +1137,10 @@ class Unit(UnitBase, abstract=True):
             if not self.is_lenient:
                 return None
             return exception.partial
+        elif isinstance(exception, RefineryImportMissing):
+            self.log_fail(F'dependencies missing; install {exception.install}')
         else:
-            self.log_warn(F'unexpected exception of type {exception.__class__.__name__}; {exception!s}')
+            self.log_fail(F'unexpected exception of type {exception.__class__.__name__}; {exception!s}')
 
         if self.log_debug():
             import traceback
@@ -1257,7 +1312,7 @@ class Unit(UnitBase, abstract=True):
         for last, chunk in lookahead(self):
             if (
                 not last
-                and (self._framehandler.unframed or self._framehandler.framebreak)
+                and self._framehandler.framebreak
                 and not chunk.endswith(B'\n')
             ):
                 chunk.extend(B'\n')
@@ -1345,6 +1400,16 @@ class Unit(UnitBase, abstract=True):
     def process(self, data: ByteString) -> Union[Optional[ByteString], Iterable[ByteString]]:
         return data
 
+    @classmethod
+    def log_fail(cls, *messages, clip=False) -> bool:
+        """
+        Log the message if and only if the current log level is at least `refinery.units.LogLevel.ERROR`.
+        """
+        rv = cls.logger.isEnabledFor(LogLevel.ERROR)
+        if rv and messages:
+            cls.logger.error(cls._output(*messages, clip=clip))
+        return rv
+
     @classmethod
     def log_warn(cls, *messages, clip=False) -> bool:
         """
@@ -1423,7 +1488,6 @@ class Unit(UnitBase, abstract=True):
         base.add_argument('-0', '--devnull', action='store_true', help='Do not produce any output.')
         base.add_argument('-v', '--verbose', action='count', default=0,
             help='Specify up to two times to increase log level.')
-        argp.add_argument('--debug-timing', dest='dtiming', action='store_true', help=SUPPRESS)
 
         if cls.is_reversible:
             base.add_argument('-R', '--reverse', action='store_true', help='Use the reverse operation.')
@@ -1499,7 +1563,6 @@ class Unit(UnitBase, abstract=True):
             unit.args.quiet = args.quiet
             unit.args.lenient = args.lenient
             unit.args.squeeze = args.squeeze
-            unit.args.dtiming = args.dtiming
             unit.args.nesting = args.nesting
             unit.args.reverse = args.reverse
             unit.args.devnull = args.devnull
@@ -1534,7 +1597,6 @@ class Unit(UnitBase, abstract=True):
         self._chunks = None
 
         keywords.update(dict(
-            dtiming=False,
             nesting=0,
             reverse=False,
             squeeze=False,
@@ -1546,14 +1608,24 @@ class Unit(UnitBase, abstract=True):
         self.args = DelayedArgumentProxy(Namespace(**keywords), list(keywords))
         self.log_detach()
 
+    _SECRET_DEBUG_TIMING_FLAG = '--debug-timing'
+
     @classmethod
-    def run(cls, argv=None, stream=None) -> None:
+    def run(cls: Union[Type[Unit], Executable], argv=None, stream=None) -> None:
         """
         Implements command line execution. As `refinery.units.Unit` is an `refinery.units.Executable`,
         this method will be executed when a class inheriting from `refinery.units.Unit` is defined in
         the current `__main__` module.
         """
         argv = argv if argv is not None else sys.argv[1:]
+        start_clock = None
+
+        if cls._SECRET_DEBUG_TIMING_FLAG in argv:
+            from time import process_time
+            argv.remove(cls._SECRET_DEBUG_TIMING_FLAG)
+            start_clock = process_time()
+            cls.logger.setLevel(logging.INFO)
+            cls.logger.info('starting clock: {:.4f}'.format(start_clock))
 
         if stream is None:
             stream = open(os.devnull, 'rb') if sys.stdin.isatty() else sys.stdin.buffer
@@ -1588,11 +1660,9 @@ class Unit(UnitBase, abstract=True):
             if loglevel:
                 unit.log_level = loglevel
 
-            if unit.args.dtiming:
-                from time import process_time
+            if start_clock:
                 unit.log_level = min(unit.log_level, LogLevel.INFO)
-                start_clock = process_time()
-                unit.logger.info('starting clock: {:.4f}'.format(start_clock))
+                unit.logger.info('unit launching: {:.4f}'.format(start_clock))
 
             try:
                 with open(os.devnull, 'wb') if unit.args.devnull else sys.stdout.buffer as output:
@@ -1604,7 +1674,7 @@ class Unit(UnitBase, abstract=True):
             except OSError:
                 pass
 
-            if unit.args.dtiming:
+            if start_clock:
                 stop_clock = process_time()
                 unit.logger.info('stopping clock: {:.4f}'.format(stop_clock))
                 unit.logger.info('time delta was: {:.4f}'.format(stop_clock - start_clock))
