@@ -41,6 +41,7 @@ class esc(Unit):
         unicode : arg.switch('-u', help='Use unicode escape sequences and UTF-8 encoding.') = False,
         greedy  : arg.switch('-g', help='Replace \\x by x and \\u by u when not followed by two or four hex digits, respectively.') = False,
         quoted  : arg.switch('-q', help='Remove enclosing quotes while decoding and add them for encoding.') = False,
+        bare    : arg.switch('-b', help='Do not escape quote characters.') = False,
         expand  : arg.switch('-p', help='Decode sequences of the form \\uHHLL as two bytes when the upper byte is nonzero.') = False,
     ) -> Unit: pass  # noqa
 
@@ -57,19 +58,24 @@ class esc(Unit):
         def unescape(match):
             c = match[1]
             if len(c) > 1:
-                if c[0] in B'u':  # unicode
+                if c[0] == 0x75:
+                    # unicode
                     upper = int(c[1:3], 16)
                     lower = int(c[3:5], 16)
                     if self.args.expand:
                         return bytes((upper, lower))
                     return bytes((lower,))
-                if c[0] in B'x':  # hexadecimal
+                elif c[0] == 0x78:
+                    # hexadecimal
                     return bytes((int(c[1:3], 16),))
+                else:
+                    # octal escape sequence
+                    return bytes((int(c, 8) & 0xFF,))
             elif c in B'ux':
                 return c if self.args.greedy else match[0]
             return self._UNESCAPE.get(c, c)
         data = re.sub(
-            RB'\\(u[a-fA-F0-9]{4}|x[a-fA-F0-9]{2}|.)', unescape, data)
+            RB'\\(u[a-fA-F0-9]{4}|x[a-fA-F0-9]{2}|[0-7]{3}|.)', unescape, data)
         return data
 
     def reverse(self, data):
@@ -80,7 +86,10 @@ class esc(Unit):
                 def escape(match):
                     c = match[0][0]
                     return self._ESCAPE.get(c, RB'\x%02x' % c)
-                string = re.sub(RB'[\x00-\x1F\x22\x27\x5C\x7F-\xFF]', escape, data)
+                pattern = RB'[\x00-\x1F\x22\x27\x5C\x7F-\xFF]'
+                if self.args.bare:
+                    pattern = RB'[\x00-\x1F\x5C\x7F-\xFF]'
+                string = re.sub(pattern, escape, data)
             else:
                 string = bytearray(4 * len(data))
                 for k in range(len(data)):
