@@ -1,15 +1,14 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 from fnmatch import fnmatch
-import openpyxl
-import xlrd2 as xlrd
+
 import re
 import io
 import defusedxml
 import functools
 
-from ... import arg, Unit
-from ....lib.structures import MemoryFile
+from refinery.units import arg, Unit
+from refinery.lib.structures import MemoryFile
 
 
 defusedxml.defuse_stdlib()
@@ -141,6 +140,16 @@ class xlxtr(Unit):
             references = [SheetReference('*')]
         super().__init__(references=references)
 
+    @Unit.Requires('xlrd2', optional=False)
+    def _xlrd():
+        import xlrd2
+        return xlrd2
+
+    @Unit.Requires('openpyxl', optional=False)
+    def _openpyxl():
+        import openpyxl
+        return openpyxl
+
     def _rcmatch(self, sheet_index, sheet_name, row, col):
         assert row > 0
         assert col > 0
@@ -179,7 +188,7 @@ class xlxtr(Unit):
 
     def _process_old(self, data):
         with io.StringIO() as logfile:
-            wb = xlrd.open_workbook(file_contents=data, logfile=logfile, verbosity=self.args.verbose - 1, on_demand=True)
+            wb = self._xlrd.open_workbook(file_contents=data, logfile=logfile, verbosity=self.args.verbose - 1, on_demand=True)
             logfile.seek(0)
             for entry in logfile:
                 entry = entry.strip()
@@ -196,7 +205,7 @@ class xlxtr(Unit):
                     yield from self._get_value(k, name, sheet.cell_value, row, col)
 
     def _process_new(self, data):
-        workbook = openpyxl.load_workbook(MemoryFile(data), read_only=True)
+        workbook = self._openpyxl.load_workbook(MemoryFile(data), read_only=True)
         for ref in self.args.references:
             ref: SheetReference
             for k, name in enumerate(workbook.sheetnames):
