@@ -293,7 +293,8 @@ class pemeta(Unit):
                 dll = dll[:-4]
             imports = info.setdefault(dll, [])
             for imp in idd.imports:
-                imports.append(imp.name.decode('ascii'))
+                name = imp.name and imp.name.decode('ascii') or F'@{imp.ordinal}'
+                imports.append(name)
         return info
 
     def parse_header(cls, pe: PE, data=None) -> dict:
@@ -328,7 +329,7 @@ class pemeta(Unit):
                     info = guess_version(idv)
                 if not info:
                     continue
-                rich.append(str(info))
+                rich.append(F'[{idv:08x}] {info}')
             header_information['RICH'] = rich
 
         characteristics = [
