@@ -32,9 +32,13 @@ class stego(Unit):
             parts=tuple(arg.as_option(p, PIXEL_PART) for p in parts)
         )
 
-    def process(self, data):
+    @Unit.Requires('Pillow', optional=False)
+    def _image():
         from PIL import Image
-        image = Image.open(MemoryFile(data))
+        return Image
+
+    def process(self, data):
+        image = self._image.open(MemoryFile(data))
         width, height = image.size
         for y in range(height):
             yield bytearray(
