@@ -1,18 +1,18 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-try:
-    from Registry.Registry import Registry
-except ModuleNotFoundError:
-    Registry = None
-
-from . import PathExtractorUnit, UnpackResult
-from ...lib.structures import MemoryFile
+from refinery.units.formats import PathExtractorUnit, UnpackResult
+from refinery.lib.structures import MemoryFile
 
 
 class winreg(PathExtractorUnit):
     """
     Extract values from a Windows registry hive.
     """
+    @PathExtractorUnit.Requires('python-registry', optional=False)
+    def _registry():
+        from Registry.Registry import Registry
+        return Registry
+
     def _walk(self, key, *path):
         here = '/'.join(path)
         if not self._check_reachable(here):
@@ -26,5 +26,5 @@ class winreg(PathExtractorUnit):
 
     def unpack(self, data):
         with MemoryFile(data) as stream:
-            root = Registry(stream).root()
+            root = self._registry(stream).root()
             yield from self._walk(root, root.name())
