@@ -14,17 +14,6 @@ from .. import arg, Unit
 from ...lib.argformats import sliceobj
 
 
-def check_variable_name(name: str) -> str:
-    """
-    All single-letter, uppercase variable names are reserved.
-    """
-    if len(name) == 1 and name.upper() == name:
-        raise ValueError('Single uppercase letter variable names are reserved.')
-    if not name.isidentifier():
-        raise ValueError('Variable names must be identifiers.')
-    return name
-
-
 class FrameSlicer(Unit, abstract=True):
 
     def __init__(self, *slice: arg(
