@@ -15,12 +15,12 @@ class iffp(ConditionalUnit):
     patterns are the following: {", ".join(_PATTERNS)}.
     """
 
-    def __init__(self, *patterns: arg.choice(metavar='pattern', choices=_PATTERNS), negate=False):
-        super().__init__(negate=negate, patterns=patterns)
+    def __init__(self, *patterns: arg.choice(metavar='pattern', choices=_PATTERNS), negate=False, temporary=False):
+        super().__init__(negate=negate, temporary=temporary, patterns=patterns)
 
     def match(self, chunk):
         for name in self.args.patterns:
             p: pattern = _PATTERNS[name]
-            if p.compiled.fullmatch(chunk):
+            if p.fullmatch(chunk):
                 return True
         return False
