@@ -63,6 +63,7 @@ class xtp(PatternExtractor):
         'comodoca.com'        : 1,
         'curl.haxx.se'        : 1,
         'digicert.com'        : 1,
+        'dublincore.org'      : 1,
         'github.com'          : 3,
         'globalsign.com'      : 1,
         'globalsign.net'      : 1,
@@ -70,6 +71,7 @@ class xtp(PatternExtractor):
         'google.com'          : 4,
         'gov'                 : 2,
         'iana.org'            : 1,
+        'intel.com'           : 1,
         'live.com'            : 1,
         'microsoft.com'       : 1,
         'msdn.com'            : 1,
