@@ -152,7 +152,7 @@ class peek(HexViewer):
 
         metrics = self._get_metrics(len(data), self.args.lines, padding)
         sepsize = metrics.hexdump_width
-        txtsize = metrics.argument or sepsize
+        txtsize = self.args.width or sepsize
 
         if self.args.lines and data:
             if self.args.esc:
@@ -185,7 +185,6 @@ class peek(HexViewer):
                     del meta['magic']
                 entropy_percent = meta['entropy'] * 100.0
                 meta['entropy'] = F'{entropy_percent:.2f}%'
-                meta['ic']
             if index is not None:
                 meta['index'] = index
             for line in self._peekmeta(metrics.hexdump_width, separator(), **meta):
